import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit } from '@angular/core';
import { YaReadyEvent } from '../../interfaces/ya-ready-event';
import { YaMapComponent } from '../ya-map/ya-map.component';
import * as i0 from "@angular/core";
/**
 * Control types.
 */
export type YaControlType = 'Button' | 'FullscreenControl' | 'GeolocationControl' | 'ListBox' | 'ListBoxItem' | 'RouteButton' | 'RouteEditor' | 'RoutePanel' | 'RulerControl' | 'SearchControl' | 'TrafficControl' | 'TypeSelector' | 'ZoomControl';
/**
 * The `ya-control` component wraps `ymaps.control[YaControlType]` classes from the Yandex.Maps API.
 * You can configure `ymaps.control[YaControlType]` via the component's inputs.
 * API Events can be bound only manually. You can use `ready` event to get an instance.
 *
 * <example-url>https://stackblitz.com/edit/searchcontrol?embed=1&view=preview</example-url>
 *
 * @example
 * ```html
 * <ya-map [center]="[55.761952, 37.620739]">
 *   <ya-control
 *     type="RoutePanel"
 *     [parameters]="{ options: { float: 'right' } }"
 *   ></ya-control>
 * </ya-map>
 * ```
 */
export declare class YaControlDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yaMapComponent;
    private readonly destroy$;
    private control?;
    /**
     * Control type.
     */
    type?: YaControlType;
    /**
     * Control parameters.
     */
    parameters?: any;
    /**
     * Control instance is added to a Map.
     */
    ready: EventEmitter<YaReadyEvent<any>>;
    constructor(ngZone: NgZone, yaMapComponent: YaMapComponent);
    ngOnChanges(): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YaControlDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YaControlDirective, "ya-control", never, { "type": "type"; "parameters": "parameters"; }, { "ready": "ready"; }, never, never, false, never>;
}
