import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { YaEvent } from '../../interfaces/ya-event';
import { YaReadyEvent } from '../../interfaces/ya-ready-event';
import { YaMapComponent } from '../ya-map/ya-map.component';
import * as i0 from "@angular/core";
/**
 * The `ya-placemark` directive wraps `ymaps.Placemark` class from the Yandex.Maps API.
 * You can configure it via the directive's inputs.
 * Events can be bound using the outputs of the directive.
 *
 * <example-url>https://stackblitz.com/edit/custom-placemark?embed=1&view=preview</example-url>
 *
 * @example
 * ```html
 * <ya-map [center]="[55.751952, 37.600739]">
 *   <ya-placemark [geometry]="[55.751952, 37.600739]"></ya-placemark>
 * </ya-map>
 * ```
 */
export declare class YaPlacemarkDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yaMapComponent;
    private readonly destroy$;
    private readonly eventManager;
    placemark?: ymaps.Placemark;
    /**
     * Coordinates of the placemark, or a hash describing the geometry, or a reference to the point geometry object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/Placemark.html#Placemark__param-geometry}
     */
    geometry: number[] | object | ymaps.IPointGeometry;
    /**
     * Placemark properties.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/Placemark.html#Placemark__param-properties}
     */
    properties?: ymaps.IPlacemarkProperties | ymaps.IDataManager;
    /**
     * Placemark options.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/Placemark.html#Placemark__param-options}
     */
    options?: ymaps.IPlacemarkOptions;
    /**
     * Placemark instance is added to a Map.
     */
    ready: EventEmitter<YaReadyEvent<ymaps.Placemark>>;
    /**
     * Closing the balloon.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-balloonclose}
     */
    balloonclose: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Opening a balloon on a geo object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-balloonopen}
     */
    balloonopen: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Event preceding the "drag" event.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-beforedrag}
     */
    beforedrag: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Event preceding the "dragstart" event.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-beforedragstart}
     */
    beforedragstart: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Single left-click on the object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-click}
     */
    yaclick: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Calls the element's context menu.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-contextmenu}
     */
    yacontextmenu: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Double left-click on the object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-dblclick}
     */
    yadblclick: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Dragging a geo object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-drag}
     */
    yadrag: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * End of geo object dragging.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-dragend}
     */
    yadragend: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Start of geo object dragging.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-dragstart}
     */
    yadragstart: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Change in the state of the editor for the geo object's geometry.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-editorstatechange}
     */
    editorstatechange: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Change to the geo object geometry.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IGeoObject.html#event_detail__event-geometrychange}
     */
    geometrychange: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Closing the hint.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-hintclose}
     */
    hintclose: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Opening a hint on a geo object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/GeoObject.html#event_detail__event-hintopen}
     */
    hintopen: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Map reference changed.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IParentOnMap.html#event_detail__event-mapchange}
     */
    mapchange: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Pressing the mouse button over the object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-mousedown}
     */
    yamousedown: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Pointing the cursor at the object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-mouseenter}
     */
    yamouseenter: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Moving the cursor off of the object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-mouseleave}
     */
    yamouseleave: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Moving the cursor over the object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-mousemove}
     */
    yamousemove: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Letting go of the mouse button over an object.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-mouseup}
     */
    yamouseup: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * End of multitouch.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-multitouchend}
     */
    multitouchend: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Repeating event during multitouch.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-multitouchmove}
     */
    multitouchmove: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Start of multitouch.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-multitouchstart}
     */
    multitouchstart: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Change to the object options.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/ICustomizable.html#event_detail__event-optionschange}
     */
    optionschange: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Change to the geo object overlay.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IGeoObject.html#event_detail__event-overlaychange}
     */
    overlaychange: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * The parent object reference changed.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IChild.html#event_detail__event-parentchange}
     */
    parentchange: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Change to the geo object data.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IGeoObject.html#event_detail__event-propertieschange}
     */
    propertieschange: Observable<YaEvent<ymaps.Placemark>>;
    /**
     * Mouse wheel scrolling.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/IDomEventEmitter.html#event_detail__event-wheel}
     */
    yawheel: Observable<YaEvent<ymaps.Placemark>>;
    constructor(ngZone: NgZone, yaMapComponent: YaMapComponent);
    /**
     * Handles input changes and passes them in API.
     * @param changes
     */
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Creates a placemark.
     */
    private createPlacemark;
    static ɵfac: i0.ɵɵFactoryDeclaration<YaPlacemarkDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YaPlacemarkDirective, "ya-placemark", never, { "geometry": "geometry"; "properties": "properties"; "options": "options"; }, { "ready": "ready"; "balloonclose": "balloonclose"; "balloonopen": "balloonopen"; "beforedrag": "beforedrag"; "beforedragstart": "beforedragstart"; "yaclick": "yaclick"; "yacontextmenu": "yacontextmenu"; "yadblclick": "yadblclick"; "yadrag": "yadrag"; "yadragend": "yadragend"; "yadragstart": "yadragstart"; "editorstatechange": "editorstatechange"; "geometrychange": "geometrychange"; "hintclose": "hintclose"; "hintopen": "hintopen"; "mapchange": "mapchange"; "yamousedown": "yamousedown"; "yamouseenter": "yamouseenter"; "yamouseleave": "yamouseleave"; "yamousemove": "yamousemove"; "yamouseup": "yamouseup"; "multitouchend": "multitouchend"; "multitouchmove": "multitouchmove"; "multitouchstart": "multitouchstart"; "optionschange": "optionschange"; "overlaychange": "overlaychange"; "parentchange": "parentchange"; "propertieschange": "propertieschange"; "yawheel": "yawheel"; }, never, never, false, never>;
}
