/**
 * Copied from angular/components/google-maps and updated for Yandex.Maps API.
 * {@link https://github.com/angular/components/blob/master/src/google-maps/map-event-manager.ts}
 */
import { NgZone } from '@angular/core';
import { Observable } from 'rxjs';
import { YaEvent } from '../../interfaces/ya-event';
/**
 * @internal
 */
type EventManagerTarget = {
    events: ymaps.IEventManager;
};
/**
 * Manages event on a Yandex.Maps object, ensuring that events are added only when necessary.
 * @internal
 */
export declare class EventManager {
    private readonly ngZone;
    /**
     * Listeners that were added before the target was set.
     */
    private pending;
    private listeners;
    private readonly targetStream;
    constructor(ngZone: NgZone);
    /**
     * Gets an observable that adds an event listener to the map when a consumer subscribes to it.
     * @param name
     */
    getLazyEmitter(name: string): Observable<YaEvent>;
    /**
     * Sets the current target that the manager should bind events to.
     * @param target
     */
    setTarget(target: EventManagerTarget): void;
    /**
     * Destroys the manager and clears the event listeners.
     */
    destroy(): void;
    /**
     * Clears all currently-registered event listeners.
     */
    private clearListeners;
}
export {};
